@@ -5,7 +5,7 @@ test_that("static feeds work", {
   
   skip_if_offline(host = "r-project.org")
   
-  get_station_information("memphis")
+  get_station_information("https://gbfs.biketownpdx.com/gbfs/en/station_information.json")
   
   get_system_alerts("https://gbfs.biketownpdx.com/gbfs/en/system_alerts.json")
   
@@ -13,10 +13,9 @@ test_that("static feeds work", {
   
   get_system_hours("https://gbfs.biketownpdx.com/gbfs/en/system_hours.json")
   
-  get_system_information("memphis")
+  get_system_information("https://gbfs.biketownpdx.com/gbfs/en/system_information.json")
   
-  get_system_pricing_plans("memphis")
+  get_system_regions("https://gbfs.biketownpdx.com/gbfs/en/system_regions.json")
   
-  get_system_regions("memphis")
-
+  get_system_pricing_plans("https://gbfs.bcycle.com/bcycle_greenville/system_pricing_plans.json")
 })
